"""
Created on Tue Jun 25 19:48:03 2019

@authors: king-ds
"""

import pandas as pd

def feature_extraction(df, column, stop_words):

    df['new_'+column] = df.apply(lambda x: run_helper_functions(x[column], stop_words), axis=1)
    return df


def remove_punctuations(x):

    punctuations = '''!()-[]{};:'"\,<>./?@#$%^&*_~`'''
    new_x = ''
    for char in x:
        if char not in punctuations:
            new_x = new_x + char
    return new_x

def remove_numbers(x):

    new_x = ''.join([i for i in x if not i.isdigit()])
    return new_x

def remove_stop_words(x, stop_words):

    new_x = [y for y in x.split() if y not in stop_words]
    #   new_x = " ".join(new_x)
    return new_x

def remove_one_two_letters(x):

    new_x = [y for y in x.split() if len(y) > 2]
    new_x = " ".join(new_x)
    return new_x

def lower_case(x):

    new_x = x.lower()
    return new_x

def run_helper_functions(x, stop_words):
    
    x = lower_case(x)
    x = remove_punctuations(x)
    x = remove_numbers(x)
    x = remove_one_two_letters(x)
    x = remove_stop_words(x, stop_words)
    return x


import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent

VERSION = '0.1.0'
PACKAGE_NAME = 'easyds'
AUTHOR = 'Ricardo Calura'
AUTHOR_EMAIL = 'ricardo.calura29@gmail.com'
URL = 'https://github.com/king-ds/easyds'
DOWNLOAD_URL = 'https://github.com/king-ds/easyds/archive/0.1.0.tar.gz'

LICENSE = 'MIT License'
DESCRIPTION = 'Personal Python library to make usual data science workflow easy.'
LONG_DESCRIPTION = (HERE / "README.md").read_text()
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
      'pandas',
]

SETUP_REQUIRES = [
    'pytest-runner',
]

TESTS_REQUIRE = [
    'pytest==4.4.1',
]

TEST_SUIT = 'tests'

setup(name=PACKAGE_NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      long_description_content_type=LONG_DESC_TYPE,
      author=AUTHOR,
      license=LICENSE,
      author_email=AUTHOR_EMAIL,
      url=URL,
      download=DOWNLOAD_URL,
      install_requires=INSTALL_REQUIRES,
      setup_requires=SETUP_REQUIRES,
      tests_require=TESTS_REQUIRE,
      test_suite=TEST_SUIT,
      packages=find_packages()
      )


import pandas as pd
from easyds.text_cleaner import feature_extraction

df = pd.DataFrame()
comments = ['This is good and easy to install', 'Ang bagal ng internet', 'Sana mas pabilisan pa ang serbisyo']
df['comments'] = comments
stop_words = ['ng', 'ikaw', 'and', 'is', 'pa', 'ang']


df = feature_extraction(df, 'comments', stop_words)

print(df)